import { ICivicEntry, ICivicGeneIndex, ICivicVariantIndex, IHotspotIndex, IMyCancerGenomeData, IOncoKbData, MobxCache, Mutation, OncoKbCardDataType, RemoteData } from 'cbioportal-utils';
import { CancerGene, IndicatorQueryResp } from 'oncokb-ts-api-client';
import * as React from 'react';
import { VariantAnnotation, Vues as VUE } from 'genome-nexus-ts-api-client';
export declare type AnnotationProps = {
    mutation?: Mutation;
    enableOncoKb: boolean;
    enableMyCancerGenome: boolean;
    enableHotspot: boolean;
    enableCivic: boolean;
    enableRevue: boolean;
    hotspotData?: RemoteData<IHotspotIndex | undefined>;
    oncoKbData?: RemoteData<IOncoKbData | Error | undefined>;
    oncoKbCancerGenes?: RemoteData<CancerGene[] | Error | undefined>;
    usingPublicOncoKbInstance: boolean;
    mergeOncoKbIcons?: boolean;
    oncoKbContentPadding?: number;
    pubMedCache?: MobxCache;
    resolveEntrezGeneId?: (mutation: Mutation) => number;
    resolveTumorType?: (mutation: Mutation) => string;
    myCancerGenomeData?: IMyCancerGenomeData;
    civicGenes?: RemoteData<ICivicGeneIndex | undefined>;
    civicVariants?: RemoteData<ICivicVariantIndex | undefined>;
    indexedVariantAnnotations?: RemoteData<{
        [genomicLocation: string]: VariantAnnotation;
    } | undefined>;
    userDisplayName?: string;
    hasMultipleCancerTypes?: boolean;
};
export declare type GenericAnnotationProps = {
    annotation: IAnnotation;
    enableCivic: boolean;
    enableHotspot: boolean;
    enableMyCancerGenome: boolean;
    enableOncoKb: boolean;
    enableRevue: boolean;
    mergeOncoKbIcons?: boolean;
    oncoKbContentPadding?: number;
    pubMedCache?: MobxCache;
    userDisplayName?: string;
    hasMultipleCancerTypes?: boolean;
};
export interface IAnnotation {
    isHotspot: boolean;
    is3dHotspot: boolean;
    hotspotStatus: 'pending' | 'error' | 'complete';
    oncoKbIndicator?: IndicatorQueryResp;
    oncoKbAvailableDataTypes: OncoKbCardDataType[];
    oncoKbStatus: 'pending' | 'error' | 'complete';
    oncoKbGeneExist: boolean;
    isOncoKbCancerGene: boolean;
    usingPublicOncoKbInstance: boolean;
    myCancerGenomeLinks: string[];
    civicEntry?: ICivicEntry | null;
    civicStatus: 'pending' | 'error' | 'complete';
    hasCivicVariants: boolean;
    hugoGeneSymbol: string;
    vue?: VUE;
}
export declare const DEFAULT_ANNOTATION_DATA: IAnnotation;
export declare function getAnnotationData(mutation?: Mutation, oncoKbCancerGenes?: RemoteData<CancerGene[] | Error | undefined>, hotspotData?: RemoteData<IHotspotIndex | undefined>, myCancerGenomeData?: IMyCancerGenomeData, oncoKbData?: RemoteData<IOncoKbData | Error | undefined>, usingPublicOncoKbInstance?: boolean, civicGenes?: RemoteData<ICivicGeneIndex | undefined>, civicVariants?: RemoteData<ICivicVariantIndex | undefined>, indexedVariantAnnotations?: RemoteData<{
    [genomicLocation: string]: VariantAnnotation;
} | undefined>, resolveTumorType?: (mutation: Mutation) => string, resolveEntrezGeneId?: (mutation: Mutation) => number): IAnnotation;
export declare function annotationSortMethod(a: IAnnotation, b: IAnnotation): number;
export declare function sortValue(annotation: IAnnotation): number[];
export declare function GenericAnnotation(props: GenericAnnotationProps): JSX.Element;
export default class Annotation extends React.Component<AnnotationProps, {}> {
    render(): JSX.Element;
    private getAnnotationData;
}
