import { ICivicGeneIndex, ICivicVariantIndex, IHotspotIndex, IMyCancerGenomeData, IOncoKbData, MobxCache, Mutation, RemoteData } from 'cbioportal-utils';
import { MyVariantInfo, VariantAnnotation } from 'genome-nexus-ts-api-client';
import { CancerGene } from 'oncokb-ts-api-client';
import * as React from 'react';
import { Column } from 'react-table';
import { DataTableColumn, DataTableProps } from '../dataTable/DataTable';
import { MutationColumn } from './MutationColumnHelper';
import './defaultMutationTable.scss';
export declare type DefaultMutationTableProps = {
    hotspotData?: RemoteData<IHotspotIndex | undefined>;
    oncoKbData?: RemoteData<IOncoKbData | Error | undefined>;
    myCancerGenomeData?: IMyCancerGenomeData;
    oncoKbCancerGenes?: RemoteData<CancerGene[] | Error | undefined>;
    usingPublicOncoKbInstance: boolean;
    indexedMyVariantInfoAnnotations?: RemoteData<{
        [genomicLocation: string]: MyVariantInfo;
    } | undefined>;
    indexedVariantAnnotations?: RemoteData<{
        [genomicLocation: string]: VariantAnnotation;
    } | undefined>;
    selectedTranscriptId?: string;
    enableCivic?: boolean;
    enableRevue?: boolean;
    civicGenes?: RemoteData<ICivicGeneIndex | undefined>;
    civicVariants?: RemoteData<ICivicVariantIndex | undefined>;
    pubMedCache?: MobxCache;
    columns: Column<Partial<Mutation>>[];
    appendColumns?: boolean;
} & DataTableProps<Partial<Mutation>>;
export default class DefaultMutationTable extends React.Component<DefaultMutationTableProps, {}> {
    constructor(props: any);
    static defaultProps: {
        initialSort: {
            column: MutationColumn;
        }[];
        appendColumns: boolean;
    };
    get annotationColumnData(): (RemoteData<IHotspotIndex | undefined> | RemoteData<IOncoKbData | Error | undefined> | RemoteData<Error | CancerGene[] | undefined> | RemoteData<ICivicVariantIndex | undefined> | undefined)[];
    get annotationColumnDataStatus(): import("cbioportal-utils").RemoteDataStatus;
    get indexedVariantAnnotationDataStatus(): import("cbioportal-utils").RemoteDataStatus;
    get myVariantInfoAnnotationsDataStatus(): import("cbioportal-utils").RemoteDataStatus;
    get annotationColumnAccessor(): (() => undefined) | ((mutation: Mutation) => import("../column/Annotation").IAnnotation);
    get myVariantInfoAccessor(): (mutation: Mutation) => MyVariantInfo | undefined;
    get hgvsgAccessor(): (() => undefined) | ((mutation: Mutation) => string | null);
    get hgvscAccessor(): (() => undefined) | ((mutation: Mutation) => string | null);
    get signalAccessor(): (() => undefined) | ((mutation: Mutation) => import("cbioportal-utils").IExtendedSignalMutation);
    get clinvarAccessor(): (mutation: Mutation) => import("genome-nexus-ts-api-client").Clinvar | undefined;
    get initialSortRemoteData(): (RemoteData<any> | undefined)[];
    protected getDefaultColumnAccessor(columnKey: MutationColumn): ((mutation: Mutation) => import("../column/Annotation").IAnnotation) | ((mutation: Mutation) => MyVariantInfo | undefined) | ((mutation: Mutation) => string | null) | ((mutation: Mutation) => import("cbioportal-utils").IExtendedSignalMutation) | ((mutation: Mutation) => import("genome-nexus-ts-api-client").Clinvar | undefined) | undefined;
    protected getDefaultColumnCellRender(columnKey: MutationColumn): ((column: any) => JSX.Element) | undefined;
    get columns(): {
        accessor?: string | string[] | import("react-table").AccessorFunction<Partial<Mutation>> | undefined;
        id?: string | undefined;
        aggregate?: import("react-table").Aggregator | undefined;
        width?: number | undefined;
        maxWidth?: number | undefined;
        expander?: boolean | undefined;
        columns?: Column<Partial<Mutation>>[] | undefined;
        pivot?: boolean | undefined;
        sortable?: boolean | undefined;
        show?: boolean | undefined;
        minWidth?: number | undefined;
        resizable?: boolean | undefined;
        filterable?: boolean | undefined;
        sortMethod?: import("react-table").SortFunction | undefined;
        defaultSortDesc?: boolean | undefined;
        Aggregated?: import("react-table").TableCellRenderer;
        Pivot?: import("react-table").PivotRenderer;
        PivotValue?: import("react-table").TableCellRenderer;
        Expander?: import("react-table").TableCellRenderer;
        Cell?: import("react-table").TableCellRenderer;
        className?: string | undefined;
        style?: object | undefined;
        getProps?: import("react-table").ReactTableFunction | undefined;
        filterAll?: boolean | undefined;
        filterMethod?: import("react-table").FilterFunction | import("react-table").DefaultFilterFunction | undefined;
        Filter?: import("react-table").FilterRender | undefined;
        Footer?: import("react-table").TableCellRenderer;
        footerClassName?: string | undefined;
        footerStyle?: object | undefined;
        getFooterProps?: import("react-table").ReactTableFunction | undefined;
        Header?: import("react-table").TableCellRenderer;
        headerClassName?: string | undefined;
        headerStyle?: object | undefined;
        getHeaderProps?: import("react-table").ReactTableFunction | undefined;
    }[];
    render(): JSX.Element;
    protected onSearch(searchText: string, visibleSearchableColumns: DataTableColumn<Mutation>[]): void;
}
